@@ -29,6 +29,9 @@ def cmd_init(reference_issue: str = ""):
             "iteration": "",
         }
         with open(".doing-cli-config.yml", "w") as file:
+            file.write("# doing cli configuration file\n")
+            file.write("# docs: https://github.com/ing-bank/doing-cli\n\n")
+            yaml.dump(required_params, file)
             yaml.dump(required_params, file)
             console.print("[dark_orange3]>[/dark_orange3] Created new .doing-cli-config.yml file")
             console.print("\t[dark_orange3]>[/dark_orange3] Please fill in required parameters.")
@@ -48,6 +51,8 @@ def cmd_init(reference_issue: str = ""):
     required_params["iteration"] = workitem[1]
 
     with open(".doing-cli-config.yml", "w") as file:
+        file.write("# doing cli configuration file\n")
+        file.write("# docs: https://github.com/ing-bank/doing-cli\n\n")
         yaml.dump(required_params, file)
         console.print("[dark_orange3]>[/dark_orange3] Create new .doing-cli-config.yml file")
         console.print(
